@@ -72,7 +72,7 @@ int complete_handler(void)
     return sharedShell;
 }
 
-- initWithEnvironment:(STEnvironment *)env
+- initWithConversation:(STConversation *)conv
 {
     self = [super init];
     
@@ -89,7 +89,8 @@ int complete_handler(void)
     scriptsManager = RETAIN([STScriptsManager defaultManager]);
     prompt = @"StepTalk > ";
     
-    conversation = [[STConversation alloc] initWithEnvironment:env language:nil];
+    conversation = RETAIN(conv);
+    
     /* FIXME: make this more clever for completion handler */
     if(!sharedShell)
     {
@@ -147,31 +148,28 @@ int complete_handler(void)
 
 - (STEnvironment *)environment
 {
-    return [conversation environment];
+    return [conversation context];
 }
 
 - (void)run
 {
-    STEnvironment *env = [conversation environment];
+    STEnvironment *env;
     NSString      *line;
     id             result;
-        
-    [env setCreatesUnknownObjects:YES];
-    
-    /* Add standard objects */
-    [env setObject:self forName:@"Shell"];
-    [env setObject:self forName:@"Transcript"];
-    [env setObject:objectStack forName:@"Objects"];
-
-    [env setObject:[NSFileManager defaultManager] forName:@"FileManager"];
-
-    /* FIXME: This is unsafe !*/
-    [env setObject:env forName:@"Environment"];
-
+            
     [self showLine:@"Welcome to the StepTalk shell."];
     
     // NSLog(@"Environment %@", env);
 
+    if(![conversation isKindOfClass:[STRemoteConversation class]])
+    {
+        completionEnabled = YES;
+    }
+    else
+    {
+        [self showLine:@"Note: Completion disabled for distant conversation"];
+    }    
+    
     while(1)
     {
         line = [self readLine];
@@ -202,7 +200,6 @@ int complete_handler(void)
 }
 - (id)executeLine:(NSString *)line
 {
-    STEnvironment *env = [conversation environment];
     NSString      *cmd;
     id             result = nil;
 
@@ -210,20 +207,18 @@ int complete_handler(void)
 
     cmd = [line stringByAppendingString:@" "];
     NS_DURING
-        result = [conversation runScriptFromString:cmd];
+        [conversation interpretScript:cmd];
+        result = [conversation result];
     NS_HANDLER
         [self showException:localException];
     NS_ENDHANDLER
 
-    [env setObject:line forName:@"LastCommand"];
-    [env setObject:result forName:@"LastObject"];
-    
     return result;
 }
 
 - (NSString *)readLine
 {
-    const char *str;
+    char       *str;
     NSString   *actualPrompt = prompt;
     NSString   *line = @"";
     BOOL        done = NO;
@@ -261,7 +256,7 @@ int complete_handler(void)
 
 - (int)completion
 {
-    STEnvironment *env = [conversation environment];
+    STEnvironment *env;
     NSEnumerator  *enumerator;
     NSMutableSet  *set;
     NSString      *match;
@@ -271,6 +266,11 @@ int complete_handler(void)
     int pos = 0;
     int c;
     
+    if(!completionEnabled)
+    {
+        return 0;
+    }
+    
     if(rl_point <= 0)
     {
         return 0;
@@ -305,6 +305,7 @@ int complete_handler(void)
         }
     }
 
+    env = [conversation context];
     enumerator = [[env knownObjectNames] objectEnumerator];
     while( (str = [enumerator nextObject]) )
     {
