@@ -26,29 +26,38 @@
 
 #import <Foundation/NSObject.h>
 
-@class STLanguage;
 @class STEngine;
-@class STEnvironment;
+@class STContext;
 
-@interface STConversation:NSObject
+@protocol STConversation
+/** Set language for the receiver. */
+- (void)setLanguage:(NSString *)newLanguage;
+- (NSString *)language;
+- (bycopy NSArray *)knownLanguages;
+
+/** Interpret given string as a script in the receiver environment. */
+- (void)interpretScript:(bycopy NSString *)aString;
+// - (void)interpretScript:(bycopy NSString *)aString inLanguage:(NSString *)lang;
+
+- (id)result;
+- (bycopy id)resultByCopy;
+@end
+
+@interface STConversation:NSObject<STConversation>
 {
+    STEngine      *engine;
+    NSString      *languageName;
+    STContext     *context;
+    id             returnValue;
 }
-/*
-+ conversationWithApplication:(NSString *)appName
-                     language:(NSString *)langName;
-*/                     
-+ conversationWithEnvironment:(STEnvironment *)env 
-                     language:(NSString *)langName;
-                   
-- initWithEnvironment:(STEnvironment *)env 
-             language:(NSString *)aString;
+- initWithContext:(STContext *)aContext 
+         language:(NSString *)aLanguage;
 
 - (void)setLanguage:(NSString *)newLanguage;
 - (NSString *)language;
 
-- (STEnvironment *)environment;
-- (BOOL)isResumable;
-- (BOOL)resume;
+- (STContext *)context;
 
+/* Depreciated */
 - (id)runScriptFromString:(NSString *)aString;
 @end
