@@ -3,7 +3,7 @@
  
     Copyright (c) 2002 Free Software Foundation
  
-    Written by: Stefan Urbanek <urbanek@host.sk>
+    Written by: Stefan Urbanek
     Date: 2003 Sep 21
    
     This file is part of the StepTalk project.
@@ -26,24 +26,12 @@
 
 #import "STConversation.h"
 
+#import <Foundation/NSDebug.h>
 #import <Foundation/NSException.h>
 
-#import "STEngine.h"
 #import "STEnvironment.h"
-#import "STLanguage.h"
-
-// FIXME: add these two:
-// @class STDistantEnvironment;
-// @class STDistantConversation;
-
-@interface STConcreteLocalConversation:NSObject
-{
-    STLanguage    *lanuage;
-    STEngine      *engine;
-    NSString      *languageName;
-    STEnvironment *environment;
-}
-@end
+#import "STEngine.h"
+#import "STLanguageManager.h"
 
 @implementation STConversation
 /** Creates a new conversation with environment created using default 
@@ -52,118 +40,87 @@
 {
     STEnvironment *env = [STEnvironment environmentWithDefaultDescription];
     
-    return AUTORELEASE([[self alloc] initWithEnvironment:env language:nil]);
-}
-/** Creates a new conversation with environment created using default 
-    description and language with name <var>langName</var>. */
-+ conversationWithEnvironment:(STEnvironment *)env 
-                     language:(NSString *)langName
-{
-    STConversation *c;
-
-/* FIXME: use this:
-    if([env isKindOfClass:[STDistantEnvironment class]])
-    {
-        c = [[STDistantConversation alloc] initWithEnvironment:env language:langName];
-    }
-    else
-    {
-        c = [[STConcreteLocalConversation alloc] initWithEnvironment:env language:langName];
-    }
-*/
-    c = [[STConcreteLocalConversation alloc] initWithEnvironment:env language:langName];
- 
-    return AUTORELEASE(c);
+    NSLog(@"DEPRECATED");
+    return AUTORELEASE([[self alloc] initWithContext:env language:nil]);
 }
 
-- initWithEnvironment:(STEnvironment *)env 
-             language:(NSString *)langName
+- (bycopy id)resultByCopy
 {
-    [self dealloc];
-    
-    return [[STConcreteLocalConversation alloc] initWithEnvironment:env language:langName];
+    return [self result];
 }
 
-- (void)setLanguage:(NSString *)newLanguage
-{
-    [self subclassResponsibility:_cmd];
-}
-
-/** Return name of the language used in the receiver conversation */
-- (NSString *)language
-{
-    [self subclassResponsibility:_cmd];
-    return nil;
-}
-- (STEnvironment *)environment
-{
-    [self subclassResponsibility:_cmd];
-    return nil;
-}
 - (id)runScriptFromString:(NSString *)aString
 {
-    [self subclassResponsibility:_cmd];
-    return nil;
+    NSLog(@"Warning: runScriptFromString: in STConversation is deprecated, use -interpretScript: and -returnVale");
+    [self interpretScript:aString];
+    return [self result];
+}
+
+/** Returns all languages that are known in the receiver. Should be used by
+    remote calls instead of NSLanguage query which gives local list of
+    languages. */
+- (NSArray *)knownLanguages
+{
+    return [[STLanguageManager defaultManager] availableLanguages];
 }
-- (BOOL)isResumable
-{
-    return NO;
-}
-- (BOOL)resume
-{
-    [self subclassResponsibility:_cmd];
-    return NO;
-}
-@end
 
-@implementation STConcreteLocalConversation
 /** Creates a new conversation with environment created using default 
     description and language with name <var>langName</var>. */
 + conversationWithEnvironment:(STEnvironment *)env 
                    language:(NSString *)langName
 {
     STConversation *c;
-    c = [[self alloc] initWithEnvironment:env language:langName];
+ 
+    NSLog(@"WARNING: +[STConversaion conversationWithEnvironment:language:] is deprecated, "
+          @" use conversationWithContext:language: instead.");
+ 
+    c = [[self alloc] initWithContext:env language:langName];
     return AUTORELEASE(c);
 }
 
 - initWithEnvironment:(STEnvironment *)env 
              language:(NSString *)langName
 {
+    NSLog(@"WARNING: -[STConversaion initWithEnvironment:language:] is deprecated, "
+          @" use initWithContext:language: instead.");
+
+    return [self initWithContext:env language:langName];
+}
+
+- initWithContext:(STContext *)aContext
+         language:(NSString *)aLanguage
+{
+    STLanguageManager  *manager = [STLanguageManager defaultManager];
     self = [super init];
 
-    if(!env)
-    {
-        [NSException raise:@"STConversationException"
-                     format:@"Unspecified environment for a conversation"];
-        [self dealloc];
-        return nil;
-    }
+    NSDebugLLog(@"STConversation",@"Creating conversation %@", self);
 
-    if(!langName || [langName isEqual:@""])
+    if(!aLanguage || [aLanguage isEqual:@""])
     {
-        languageName = RETAIN([STLanguage defaultLanguageName]);
+        languageName = RETAIN([manager defaultLanguage]);
     }    
     else
     {
-        languageName = RETAIN(langName);
+        languageName = RETAIN(aLanguage);
     }
     
-    environment = RETAIN(env);
+    context = RETAIN(aContext);
     return self;
 }
 
 - (void)dealloc
 {
+    NSDebugLLog(@"STConversation",@"Deallocating conversation %@", self);
     RELEASE(languageName);
-    RELEASE(environment);
+    RELEASE(context);
     RELEASE(engine);
+    RELEASE(returnValue);
     [super dealloc];
 }
 
 - (void)_createEngine
 {
-    ASSIGN(engine,[STEngine engineForLanguageWithName:languageName]);
+    ASSIGN(engine,[STEngine engineForLanguage:languageName]);
 }
 
 - (void)setLanguage:(NSString *)newLanguage
@@ -183,14 +140,28 @@
 }
 - (STEnvironment *)environment
 {
-    return environment;
+    NSLog(@"WARNING: -[STConversaion environment] is deprecated, "
+          @" use -context instead.");
+
+    return (STEnvironment *)context;
 }
-- (id)runScriptFromString:(NSString *)aString
+- (STContext *)context
+{
+    return context;
+}
+
+- (void)interpretScript:(NSString *)aString
 {
     if(!engine)
     {
         [self _createEngine];
     }
-    return [engine executeCode: aString inEnvironment:environment];
+    
+    ASSIGN(returnValue, [engine interpretScript: aString 
+                                      inContext: context]);
+}
+- (id)result
+{
+    return returnValue;
 }
 @end
